@@ -5,7 +5,7 @@
 import sys
 import os
 import locale
-VERSION = "1.0.1"
+VERSION = "1.0.3"
 
 try: locale.setlocale(locale.LC_ALL, '')
 except locale.Error: pass
@@ -19,9 +19,9 @@ elif os.name == "posix":
   elif "HOME" in os.environ:
     osname = "posix"
 else:
-  print "Your platform is not supported by pydance. In particular, it"
-  print "doesn't seem to be Win32, Mac OS X, or a Unix that sets $HOME."
-  sys.exit(2)
+  raise SystemExit(
+    "Your platform is not supported by pydance. In particular, it\n" +
+    "doesn't seem to be Win32, Mac OS X, or a Unix that sets $HOME.")
 
 # SDL_mixer is the bane of my existance.
 if osname == 'posix': # We need to force stereo in many cases.
@@ -33,10 +33,10 @@ pydance_path = sys.argv[0]
 if osname == "posix":
   pydance_path = os.path.split(os.path.realpath(pydance_path))[0]
 else: pydance_path = os.path.split(os.path.abspath(pydance_path))[0]
-sys.path.append(pydance_path)
+sys.path.insert(0, pydance_path)
 
 if os.path.exists(os.path.join(pydance_path, "pydance.zip")):
-  sys.path.append(os.path.join(pydance_path, "pydance.zip"))
+  sys.path.insert(0, os.path.join(pydance_path, "pydance.zip"))
 
 # Set up some names for commonly referenced directories
 image_path = os.path.join(pydance_path, "images")
@@ -93,6 +93,7 @@ default_conf = {
   "usepsyco": 1,
   "autogen": 1,
   "centerconfirm": 1,
+  "songinfoscreen": 1,
 
   # Player config
   "spin": 0,
@@ -144,6 +145,34 @@ game_config = dict([(k, mainconfig[k]) for k in
                     ["battle", "scoring", "combo", "grade", "judge",
                      "judgescale", "life", "secret", "lifebar", "onilives"]])
 
+
+# The list of options that are safe to change between songs on a
+# playlist
+# Each tuple has the following entries:
+# 0. Option "key", like the one used in the options.OPTIONS dictionary
+# 1. A dictionary of option values that require special displaying:
+#    the key is the value of the option and the value is a string that
+#    should be shown on the song info screen if that option is
+#    selected.  If there is no key for a particular option, the string
+#    that is displayed for that value in the option menu is used.
+#    E.g. for the "jumps" option, value 0 will map to "No Jumps" while
+#    value 2 is not in the dictionary so will display "Wide".
+
+changeable_between = [('speed', {}),
+                      ('transform', {}),
+                      ('size', {}),
+                      ('fade', {}),
+                      ('accel', {}),
+                      ('scale', {}),
+                      ('scrollstyle', {}),
+                      ('jumps', {0:"No Jumps"}),
+                      ('spin', {1:"Spin"}),
+                      ('colortype', {}),
+                      ('dark', {1:"Dark"}),
+                      ('holds', {0:"No Holds"})
+                      ]
+
+
 pygame.init()
 
 # Fonts
@@ -174,4 +203,3 @@ DIFF_COLORS = { "BEGINNER": colors.color["white"],
                 "CRAZY": colors.color["purple"],
                 "EXPERT": colors.color["purple"]
                 }
-
